Authors — Riskfolio-Lib 0.1 documentation

# Authors

- Dany Cajas

I’m a BSc in Economic Engineering at Universidad Nacional de Ingeniería and MA in Finance at Universidad del Pacífico. I am very interested in quantitative finance. For more about me, you can visit my blog financioneroncios, visit my linkedin or write me to dany.cajas.n@uni.pe

I like to learn and apply my knowledge in practical applications; for this reason I started my blog to practice and share in my native language the things that I’ve been learned until now. One topic that always have been very interesting to me is portfolio optimization, however I realized that open-source libraries (python) are few (there are among one and four) and are mainly focused on mean variance optimization, ignore advances on other convex risk measures (like CVaR, MAD, Maximum Drawdown, etc.) and other estimations techniques like robust estimates, Black Litterman and risk factors models. For this reason I developed Riskfolio-Lib, a well documented library that will benefit academics and practicioners to apply complex optimizations models in their strategic asset allocation process.